# yamlay

YAMLay - YAML layering (upgrade/merge) tool

This is a placeholder repository for the YAMLay project, which aims to provide a tool for upgrading and merging YAML files. The project is currently in the planning stage, and the CLI and core functionality will be implemented soon.

- [YAMLay on Github](https://github.com/taishi-hashimoto/yamlay)
- [YAMLay on PyPI](https://pypi.org/project/yamlay/)

## Install

```bash
pip install yamlay
```

### Dependencies

- [ruamel.yaml](https://pypi.org/project/ruamel.yaml/)

## Usage

```bash
yamlay --help
```
